"""
List of bytecode and Python versions that xpython has support for
"""
# The below has extra commas for POSIX shell's taste, but that's okay
SUPPORTED_PYTHON = (
    (2, 7),
    (3, 3),
    (3, 2),
    (3, 4),
    (3, 5),
    (3, 6),
    (3, 7),
    (3, 8),
    (3, 9),
    (3, 10),
    (3, 11),
    (3, 12),
)

SUPPORTED_PYPY = ((2, 7), (3, 2), (3, 5), (3, 6), (3, 7), (3, 8), (3, 9))  # noqa

SUPPORTED_BYTECODE = (
    (2, 4),
    (2, 5),
    (2, 6),
    (2, 7),
    (3, 3),
    (3, 2),
    (3, 4),
    (3, 5),
    (3, 6),
    (3, 7),
    (3, 8),
    (3, 9),
    (3, 10),
    (3, 11),
    (3, 12),
)
